#
# spec file for package python-astropy-iers-data
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
%else
%bcond_with test
%define psuffix %{nil}
%endif

Name:           python-astropy-iers-data%{psuffix}
Version:        0.2024.11.4.0.33.34
Release:        1.2
Summary:        IERS Earth Rotation and Leap Second tables for the astropy core package
License:        BSD-3-Clause
URL:            https://github.com/astropy/astropy-iers-data
Source:         https://files.pythonhosted.org/packages/source/a/astropy-iers-data/astropy_iers_data-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module astropy-iers-data = %{version}}
BuildRequires:  %{python_module astropy}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest-remotedata}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
%endif
BuildRequires:  fdupes
BuildArch:      noarch
%python_subpackages

%description
IERS Earth Rotation and Leap Second tables for the astropy core package

Note: This package is not currently meant to be used directly by users, and only meant to be used from the core astropy package.

%prep
%autosetup -p1 -n astropy_iers_data-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# See tox.ini
%pytest -n auto -m "not hypothesis" --pyargs astropy.coordinates
%pytest -n auto -m "not hypothesis" --pyargs astropy.time
%pytest -n auto -m "not hypothesis" --pyargs astropy.utils.iers
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE.rst
%{python_sitelib}/astropy_iers_data
%{python_sitelib}/astropy_iers_data-%{version}.dist-info
%endif

%changelog
* Fri Nov  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.2024.11.4.0.33.34
  * Update IERS Earth rotation and leap second tables
* Tue Oct 22 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2024.10.21.0.33.21:
  * Bump actions/checkout from 4.2.0 to 4.2.1
  * MNT: Use hash for Action workflow versions and update if
    needed
  * Remove leading zeros in tag to make tag consistent with PyPI
    release
  * Fix continuous integration
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.2024.8.27.10.28.29
  * Tell setuptools_scm to not normalize version (fixes #17) by
    @sergiopasra in #26
  * Update IERS Earth rotation and leap second tables
- Add test multibuild and use astropy testsuite
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2024.06.24.00.31.11:
  * Update IERS Earth rotation and leap second tables
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2024.06.03.00.31.14:
  * Update IERS Earth rotation and leap second tables
* Sun May  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.2024.4.29.0.28.48
  * Update IERS Earth rotation and leap second tables
* Sun Mar 10 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.2024.3.4.0.30.17
  * Update IERS Earth rotation and leap second tables
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2024.01.29.00.30.37:
  * **Full Changelog**: https://github.com/astropy/astropy-iers-
    data/compare/v0.2023.12.25.00.30.16...v0.2024.01.29.00.30.37
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2023.12.25.00.30.16:
  * **Full Changelog**: https://github.com/astropy/astropy-iers-
    data/compare/v0.2023.12.18.00.30.18...v0.2023.12.25.00.30.16
* Sat Dec  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.2023.12.4.0.30.20
  * No upstream changelog, now required by astropy v6.0
* Fri Sep 15 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.2023.9.11.0.29.46
- Required by astropy 6.0dev
